@@ -4,6 +4,7 @@ from prelude_parser._prelude_parser import (
     Entry,
     Field,
     Form,
+    LockState,
     Reason,
     SiteNative,
     State,
@@ -26,6 +27,7 @@ __all__ = [
     "Entry",
     "Field",
     "Form",
+    "LockState",
     "Reason",
     "SiteNative",
     "SiteNative",
